/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.Message;

import org.junit.Ignore;
import org.junit.Test;

import client.TestConfiguration;

/**
 * Client for BJM_3005_TestCase
 *
 * If the value of the @correlationScheme attribute is "sca:none" the SCA runtime MUST
 * NOT set the correlation ID
 *  
 * This test uses the JMS test runner to send a JMS message to the test composite's service.
 */
public class BJM_3005_TestCase extends BaseJMSTestRunner {

    private String requestCorrelationID;

    protected TestConfiguration getTestConfiguration() {
    	JMSTestConfiguration config = new JMSTestConfiguration();
    	config.testName          = this.getClass().getSimpleName().substring(0, 8);
    	config.input             = "BJM_3005 request message";
    	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><return>service1 operation1 invoked with BJM_3005 request message</return>";
    	config.composite         = "Test_" + config.testName + ".composite";
    	config.contributionNames = new String[] { "BJM_3005", "BJM_General", "BJM_General" + _Lang };
        config.destinationName   = "TEST_BJM_3005_Queue";

    	return config;
    }
    
    /**
     * Check the reply message.
     *
     * @param reply - the reply message
     * @return the output.
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public String checkReplyMessage( Message reply ) throws Exception {
        String output;
        String correlID = reply.getJMSCorrelationID();
        if( correlID == null || correlID.length() == 0 )
            output = super.checkReplyMessage(reply);
        else 
            output = "Reply Correlation ID: "+correlID+" should be empty/null";

        return output;
    }

    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
    
} // end class BJM_3005_TestCase