/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.DeliveryMode;
import javax.jms.Message;

import org.junit.Test;
import org.junit.Ignore;


import client.TestConfiguration;


/**
 * Client for BJM_3024_2_TestCase
 * 
 * When sending messages for a JMS binding, the SCA runtime MUST set each of the
 * JMSType, JMSDeliveryMode, JMSTimeToLive and JMSPriority headers to values
 * specified in the binding definition in the following priority order:
 * 1) the value for the header specified in the @uri attribute (highest priority);
 * 2) the value for the header specified in the operationProperties/headers element
 *    matching the operation being invoked;
 * 3) the value for the header specified in the headers element;
 * 4) the default value for the header as specified by the definition of the
 *    binding.jms/headers element (lowest priority)
 * 
 * This is the operationProperties case
 * 
 */
public class BJM_3024_2_TestCase extends BaseJMSTestRunner {

    protected TestConfiguration getTestConfiguration() {
    	JMSTestConfiguration config = new JMSTestConfiguration();
    	config.testName          = this.getClass().getSimpleName().substring(0, 10);
    	config.input             = "BJM_3024 request message";
    	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><arg0>service1 operation1 invoked with BJM_3024 request message</arg0>";
    	config.composite         = "Test_" + config.testName + ".composite";
    	config.contributionNames = new String[] { "BJM_3024_2", "BJM_General", "BJM_General" + _Lang };
        config.destinationName   = "TEST_BJM_3024_Queue";
        config.replyDestinationName   = "TEST_BJM_3024_REF_Queue";

    	return config;
    }
    
    /**
     * Check the reply message.
     *
     * @param reply - the reply message
     * @return the output.
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public String checkReplyMessage( Message reply ) throws Exception {
        
        /* we set timeToLive to 0 (infinte) in the cases we are expecting, then we should expect to see JMSExpiration = 0 as well.  
         * If we were testing for a specific timeToLive, then we would see a specific JMSExpiration, and would have to compute 
         * that from the current time and timeToLive, and allow for some small timing window too.         
         */
        
        String output;
        String type = reply.getJMSType();
        int deliveryMode = reply.getJMSDeliveryMode();
        long timeToLive = reply.getJMSExpiration();
        int priority = reply.getJMSPriority();
        if( type.equals("operationProperties") && deliveryMode == DeliveryMode.NON_PERSISTENT && timeToLive == 0 && priority == 6)
            output = super.checkReplyMessage(reply);
        else 
            output = "Reply message has JMSType: "+type+
                     ", JMSDeliveryMode: "+deliveryMode+
                     ", JMSTimeToLive: "+timeToLive+
                     "and JMSPriority: "+priority;

        return output;
    }
    
    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
    
} // end class BJM_3024_2_TestCase
