/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.BytesMessage;
import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;

import org.junit.Ignore;
import org.junit.Test;

import testClient.TestInvocation;
import client.TestConfiguration;

/**
 * Client for BJM_6004_TestCase
 * 
 * For an SCA reference with a JMS binding, when a request message is sent as part of
 * a request/response MEP, and the JMS binding has a response element with a
 * destination defined, then the SCA runtime MUST use that destination for the
 * JMSReplyTo header in the JMS message it creates for the request
 * 
 */
public class BJM_6004_TestCase extends NamedReplyJMSTestRunner {
	
    protected TestConfiguration getTestConfiguration() {
        NamedReplyJMSTestConfiguration config = new NamedReplyJMSTestConfiguration();
    	config.testName 		 = this.getClass().getSimpleName().substring(0, 8);
    	config.input 		 	 = "request message";
    	config.output[0] 		 = "JMSReplyTo is as expected";
    	config.composite 		 = "Test_" + config.testName + ".composite";
    	config.testServiceName 	 = "TestClient";
    	config.contributionNames = new String[] { "BJM_6004", "BJM_General", "BJM_General" + _Lang };
    	config.serviceInterface  = TestInvocation.class;
        config.destinationName   = "TEST_BJM_6004_Receive_Queue";
        config.calloutDestinationName = "TEST_BJM_6004_Send_Queue";
    	return config;
    }
    
    /**
     * Check the reply message.
     *
     * @param reply - the reply message
     * @return the output.
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public String checkReplyMessage( Message reply ) throws Exception {
        Queue replyTo = (Queue)reply.getJMSReplyTo();
        
        sendResponse(reply);

        // wait for half a sec to give the response time to be processed 
        Thread.sleep(500); 
        
        if (replyTo == null) {
              return "JMSReplyTo header is null";
        } else {
            if (!"TEST_BJM_6004_Response_Queue".equals(replyTo.getQueueName())) {
                return "JMSReplyTo is not as expected: " + replyTo.getQueueName();
            }
        }
        return "JMSReplyTo is as expected";
    }

    /**
     * the reference is request/response MEP so need to send a reply so it doesn't hang waiting
     */
    private void sendResponse(Message reply) throws JMSException {
        Destination x = reply.getJMSReplyTo();
        MessageProducer msgProducer = sess.createProducer(x);
        BytesMessage m = sess.createBytesMessage();
        m.setJMSCorrelationID(reply.getJMSMessageID());
        msgProducer.send(m);
    }

    private Session sess;

    public void sendRequestMessage( Session sess, Destination dest, Message request ) throws Exception {
        this.sess = sess;
        super.sendRequestMessage(sess, dest, request);
    }
    
    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
}  //  End class BJM_6004_TestCase
