/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.Message;
import javax.jms.Session;
import javax.jms.TextMessage;

import client.TestConfiguration;

/**
 * Client for BJM_6008_TestCase
 * 
 * For an SCA service with a JMS binding, when a response message is sent as part of a
 * request/response MEP where the request message included a null JMSReplyTo
 * destination and the JMS binding includes a response/destination element the SCA
 * runtime MUST send the response message to that destination  
 * 
 */
public class BJM_6008_TestCase extends NamedReplyJMSTestRunner {

	
	   protected TestConfiguration getTestConfiguration() {
	    	NamedReplyJMSTestConfiguration config = new NamedReplyJMSTestConfiguration();
	    	config.testName          = this.getClass().getSimpleName().substring(0, 8);
	    	config.input             = "BJM_6008 request message";
	    	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><return>service1 operation1 invoked with BJM_6008 request message</return>";
	    	config.composite         = "Test_" + config.testName + ".composite";
	    	config.contributionNames = new String[] { "BJM_6008", "BJM_General", "BJM_General" + _Lang };
	        config.destinationName   = "TEST_BJM_6008_Queue";
	        config.calloutDestinationName = "TEST_BJM_6008_Receive_Queue";
	 
	    	return config;
	    }

            /**
             * Create the request message ensuring that no replyToQueue is specified.
             * @param input - input string
             * @param sess - the JMS session
             * @return the request message.
             * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
             */
            public Message createRequestMessage( String input, Session sess) throws Exception {

                TextMessage textMsg = sess.createTextMessage();
                textMsg.setText("<?xml version=\"1.0\" encoding=\"UTF-8\"?><operation1>"+input+"</operation1>");

                return textMsg;
            }

}  // end class BJM_6008_TestCase
