/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.BytesMessage;
import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageProducer;
import javax.jms.Session;

import org.junit.Ignore;
import org.junit.Test;

import testClient.TestInvocation;
import client.TestConfiguration;

/**
 * Client for BJM_6014a_TestCase
 * 
 * For an SCA reference with a JMS binding and bidirectional interface, the SCA runtime
 * MUST identify the callback destination from the reference's callback service binding if
 * present, or supply a suitable callback destination if not present
 * 
 * This is the test for supplying a suitable alternative.
 * 
 */
public class BJM_6014_2_TestCase extends NamedReplyJMSTestRunner {

    private Session sess;


	protected TestConfiguration getTestConfiguration() {
    	NamedReplyJMSTestConfiguration config = new NamedReplyJMSTestConfiguration();
    	config.testName 		 = this.getClass().getSimpleName().substring(0, 10);
    	config.input 		 	 = "request";
    	config.output[0] 		 = "scaCallbackDestination property is a jms URI";
    	config.composite 		 = "Test_" + config.testName + ".composite";
    	config.testServiceName 	 = "TestClient";
    	config.contributionNames = new String[] { "BJM_6014_2", "BJM_General", "BJM_General" + _Lang };
    	config.serviceInterface  = TestInvocation.class;
        config.destinationName   = "TEST_BJM_6014_Service_Queue";
        config.calloutDestinationName = "TEST_BJM_6014_Reference_Queue";
    	return config;
    }
    
    /**
     * Check the reply message.
     *
     * @param reply - the reply message
     * @return the output.
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public String checkReplyMessage( Message reply ) throws Exception {
        String scaCallbackDestination = reply.getStringProperty("scaCallbackDestination");
        
        sendResponse(reply);
        
        if (scaCallbackDestination == null) {
        	return "scaCallbackDestination property is null";
        }
    	if (scaCallbackDestination.startsWith("jms:queue:") || scaCallbackDestination.startsWith("jms:topic:") || scaCallbackDestination.startsWith("jms:jndi:")) {
        	return "scaCallbackDestination property is a jms URI";
        }
    	return "scaCallbackDestination property is not a jms URI: " + scaCallbackDestination;
    }

    /**
     * the reference is request/response MEP so need to send a reply so it doesn't hang waiting
     */
    private void sendResponse(Message reply) throws JMSException {
        MessageProducer msgProducer = sess.createProducer(reply.getJMSReplyTo());
        BytesMessage m = sess.createBytesMessage();
        m.setJMSCorrelationID(reply.getJMSMessageID());
        msgProducer.send(m);
	}

	public void sendRequestMessage( Session sess, Destination dest, Message request ) throws Exception {
    	this.sess = sess;
    	super.sendRequestMessage(sess, dest, request);
    }
    
    
    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
}  // end class BJM_6014_2_TestCase
